@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.h 352 2005-05-07 07:21:11Z svn $
+ * $Id: RFC1867Parser.h 466 2005-07-17 05:11:07Z svn $
  *****************************************************************************/
 
 #ifndef RFC1867PARSER_H
@@ -41,10 +41,14 @@
 #undef PACKAGE_TARNAME
 #undef PACKAGE_VERSION
 #include "httpd.h"
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
 #endif
 
 #include "apr_pools.h"
-#include "util_filter.h"
 
 #undef strtoul
 
@@ -52,12 +56,6 @@
 #include <map>
 #include <string>
 
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-
 #ifdef HAVE_CONFIG_H
 #include "mod_uploader_config.h"
 #endif
@@ -69,22 +67,23 @@
 using namespace std;
 
 /**
- * RFC1867 Ϥѡ륯饹
+ * @brief RFC1867 Ϥѡ륯饹
  */
 template<class FileWriterClass>
 class RFC1867Parser
 {
 public:
     enum param_type {
+        NONE,
         TEXT,
         FILE
     };
 
     typedef struct FileContent {
-        const char * const name;
-        const char * const tmp_path;
-        const char * const mime;
-        const apr_size_t size;
+        string name;
+        string tmp_path;
+        string mime;
+        apr_size_t size;
 
         FileContent(const char *name, const char *tmp_path,
                     const char *mime, apr_size_t size)
@@ -95,27 +94,43 @@ public:
         {
 
         }
+
+        FileContent()
+            : name(),
+              tmp_path(),
+              mime(),
+              size(0)
+        {
+
+        }
     } file_content;
 
     typedef struct RFC1867Content {
         param_type type;
-        union {
-            const char *text;
-            file_content *file;
-        };
+        string text;
+        file_content file;
+
+        RFC1867Content()
+            : type(NONE),
+              text(),
+              file()
+        {
+
+        }
     } rfc1867_content;
 
-    typedef map<string, rfc1867_content *> query_map; // multimap ǤϤʤ
-    typedef pair<string, rfc1867_content *> query_pair;
+    typedef map<string, rfc1867_content> query_map; // multimap ǤϤʤ
+    typedef pair<string, rfc1867_content> query_pair;
 
     RFC1867Parser(const char *file_dir,
                   apr_size_t max_text_size, apr_size_t max_file_size,
                   apr_size_t max_item_num,
                   apr_size_t file_offset=0);
-    query_map *parse(apr_pool_t *pool, request_rec *request, const char *content_type);
+    query_map *parse(apr_pool_t *pool, request_rec *request,
+                     const char *content_type);
 
-    static void clean_tmp_file(apr_pool_t *pool, query_map *qmap);
-    static void clear_map(query_map *qmap);
+    static void clean_tmp_file(apr_pool_t *pool, query_map *qmap,
+                               bool is_strict=false);
 #ifdef DEBUG
     static void dump_map(query_map *qmap);
 #endif
@@ -145,26 +160,22 @@ private:
 
     typedef struct Handle {
         apr_pool_t * const pool;
-        request_rec * const request;
         const char * const boundary;
+        request_rec * const request;
         const apr_size_t boundary_len;
         const query_map *qmap;
-        BinString *buffer;
+        BinString buffer;
 
         Handle(apr_pool_t *pool, request_rec *request, const char *boundary,
                query_map *query_map)
             : pool(pool),
-              request(request),
               boundary(boundary),
+              request(request),
               boundary_len(strlen(boundary)),
-              qmap(query_map)
+              qmap(query_map),
+              buffer(READ_BLOCK_SIZE*3) // 3 ʾ夸ʤȤޤ
         {
-            buffer  = new BinString();
-            buffer->reserve(READ_BLOCK_SIZE*3); // 3 ʾ夸ʤȤޤ
-        }
-        ~Handle()
-        {
-            delete buffer;
+
         }
     } handle;
 
@@ -174,15 +185,15 @@ private:
     const apr_size_t max_item_num_;
     const apr_size_t file_offset_;
 
-    RFC1867Parser(const RFC1867Parser &);
-    RFC1867Parser &operator=(const RFC1867Parser &);
+    RFC1867Parser(const RFC1867Parser&);
+    RFC1867Parser &operator=(const RFC1867Parser&);
 
-    bool get_content(handle *h, const char **name, rfc1867_content **content);
-    const char *get_text_content(handle *h);
-    const char *get_file_content(handle *h, apr_size_t *file_size);
-    apr_size_t store_buffer(handle *h);
+    bool get_content(handle& h, string& name, rfc1867_content& content);
+    const char *get_text_content(handle& h);
+    const char *get_file_content(handle& h, apr_size_t *file_size);
+    apr_size_t store_buffer(handle& h);
 
-    static apr_size_t read(handle *h, char *buffer);
+    static apr_size_t read(handle& h, char *buffer);
     static const char *get_boundary(apr_pool_t *pool, const char *content_type);
     static const char *parse_header(apr_pool_t *pool,
                                     const char *input_start, const char *pattern);
