@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: TemplateLexer.h 469 2005-07-19 00:23:53Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATELEXER_H
@@ -178,16 +178,11 @@ private:
             set_input(data, length);
         }
 
-        Handle()
-        {
-            set_input(NULL, 0);
-        }
-
         void set_input(const char *data, apr_size_t length)
         {
-            input       = data;
+            input = data;
             input_start = data;
-            input_end   = data + length;
+            input_end = data + length;
         }
     } handle;
 
@@ -200,7 +195,7 @@ private:
     static token_type_str token_type_list[];
 #endif
 
-    apr_pool_t * const pool_;
+    apr_pool_t *pool_;
     apr_pool_t *temp_pool_;
 
     handle handle_;
