@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 466 2005-07-17 05:11:07Z svn $
+ * $Id: UploaderConfig.h 487 2005-08-04 18:28:09Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADERCONFIG_H
@@ -40,7 +40,11 @@
 
 #include "apr_pools.h"
 #include "apr_time.h"
+#ifdef LOCK_TYPE_MUTEX
+#include "apr_thread_mutex.h"
+#else
 #include "apr_thread_rwlock.h"
+#endif
 
 #include <cstdlib>
 
@@ -123,14 +127,17 @@ private:
     apr_pool_t *error_tmpl_pool;
     apr_pool_t *list_pool;
 #if APR_HAS_THREADS
-    apr_thread_rwlock_t *rwlock;
+#ifdef LOCK_TYPE_MUTEX
+    apr_thread_mutex_t *lock;
+#else
+    apr_thread_rwlock_t *lock;
+#endif
 #endif
-
     volatile bool is_init;
 
     void validate();
 #if APR_HAS_THREADS
-    void init_rwlock(apr_pool_t *pool, apr_pool_t *tmp_pool);
+    void init_lock(apr_pool_t *pool, apr_pool_t *tmp_pool);
 #endif
     void load_list(apr_pool_t *pool);
     void update_list(apr_pool_t *pool, apr_pool_t *tmp_pool);
