@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 461 2005-07-14 16:53:59Z svn $
+ * $Id: MmapFileWriter.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "MmapFileWriter.h"
@@ -70,7 +70,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
     const char *data;
     apr_size_t write_size;
 
-    data = static_cast<const char *>(buf);
+    data = reinterpret_cast<const char *>(buf);
 
     while (size > 0) {
         write_size = (size > block_size_) ? block_size_ : size;
@@ -79,7 +79,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             if (offset_ != block_size_) {
                 write_size = block_size_ - offset_;
 
-                memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
+                memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
                 data += write_size;
                 size -= write_size;
             }
@@ -88,7 +88,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             continue;
         }
 
-        memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
+        memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
 
         data += write_size;
         offset_ += write_size;
