@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 452 2005-07-10 18:06:57Z svn $
+ * $Id: TemplateParser.cpp 468 2005-07-18 10:11:42Z svn $
  *****************************************************************************/
 
 #include "TemplateParser.h"
@@ -118,24 +118,24 @@ apr_size_t TemplateParser::print_node(node *node)
     if (node->id == 0) {
         node->id = id++;
     }
-    cout << "\"node_" << static_cast<unsigned int>(node->id) <<  "\" [" << endl;
+    cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) <<  "\" [" << endl;
     cout << "    label = \"" << get_node_type(node) << " | <0>left | <1>center | <2>right\"" << endl;
     cout << "];" << endl;
 
     if (node->branch.left != NULL) {
-        branch_id = static_cast<unsigned int>(print_node(node->branch.left));
+        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.left));
 
-        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":0 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":0 -> \"node_" << branch_id << "\"" << endl;
     }
     if (node->branch.center != NULL) {
-        branch_id = static_cast<unsigned int>(print_node(node->branch.center));
+        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.center));
 
-        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":1 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":1 -> \"node_" << branch_id << "\"" << endl;
     }
     if (node->branch.right != NULL) {
-        branch_id = static_cast<unsigned int>(print_node(node->branch.right));
+        branch_id = reinterpret_cast<unsigned int>(print_node(node->branch.right));
 
-        cout << "\"node_" << static_cast<unsigned int>(node->id) << "\":2 -> \"node_" << branch_id << "\"" << endl;
+        cout << "\"node_" << reinterpret_cast<unsigned int>(node->id) << "\":2 -> \"node_" << branch_id << "\"" << endl;
     }
 
     return node->id;
@@ -1015,7 +1015,7 @@ inline TemplateParser::node *TemplateParser::create_node(node_type type)
 {
     if (node_pool_ == node_pool_end_) {
         node_pool_
-            = static_cast<node *>(apr_pcalloc(pool_,
+            = reinterpret_cast<node *>(apr_pcalloc(pool_,
                                                   sizeof(node)*NODE_POOL_NUM));
         node_pool_end_ = node_pool_ + NODE_POOL_NUM;
     }
@@ -1102,14 +1102,14 @@ int main(int argc, const char * const *argv)
         }
 
         if (apr_mmap_create(&file_map, fd, 0,
-                            static_cast<apr_size_t>(info.size), APR_MMAP_READ,
+                            reinterpret_cast<apr_size_t>(info.size), APR_MMAP_READ,
                             pool) != APR_SUCCESS) {
             throw "ե mmap ˼Ԥޤ";
         }
 
         TemplateLexer lexer(pool,
-                            static_cast<const char *>(file_map->mm),
-                            static_cast<apr_size_t>(info.size));
+                            reinterpret_cast<const char *>(file_map->mm),
+                            reinterpret_cast<apr_size_t>(info.size));
         TemplateParser parser(pool);
         node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
         TemplateParser::print_dot(node);
